##  Collaborate and collect data
SAP LeanIX offers collaborative capabilities that enable teams to gather data efficiently. One useful collaboration feature is [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets."), which allows gathering information from subject matter experts and those responsible for the architectural elements, modeled via subscription roles in the fact sheets, to provide insights. In case some data is already stored in a file, [Excel importing functionality](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.") can be used to transfer the information to SAP LeanIX.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275498947a441014bc39bf90a91201fd_LowRes.png)
Monitor the progress of data collection by using the different mechanisms offered by SAP LeanIX, such as the quality seal and the survey administration area, or by creating a dashboard with the targeted fields as custom chart widgets.
